#!/bin/sh

############################################################
# HRM silent install mode
############################################################
if [ "$1" = "--silent" ];
then
   SILENT=1
   SILENT_LOG="/tmp/postsetup.log"
fi

Do_print()
{
    if [ "$SILENT" = "1" ]; then
      if [ "$1" != "" ]; then
        printf "HRM:%s\n" "$1" >> $SILENT_LOG
      fi
    else
      printf "%s\n" "$1"
    fi
}

Do_rpm_UVH()
{
    if [ "$SILENT" = "1" ]; then
      rpm -U "$1" >> $SILENT_LOG 2>&1
    else
      rpm -Uvh "$1"
    fi
}


Do_rpm_IVH()
{
    if [ "$SILENT" = "1" ]; then
      rpm -i "$1" >> $SILENT_LOG 2>&1
    else
      rpm -ivh "$1"
    fi
}

Do_print "HRM 3.6.1 install script for PRIMEQUEST(Linux)"
Do_print "Copyright(C) FUJITSU LIMITED 2004-2010"
Do_print ""

############################################################
# check if login user is root
############################################################
if [ $UID != "0" ];
then
   Do_print "ERROR : login user is not root!"
   Do_print "        Please try again as root."
   exit 1
fi

FJSVhrm_RHEL=FJSVhrmsr-*.redhat.i686.rpm
#FJSVhrm_SUSE=FJSVhrmsr-*.suse.i686.rpm

#FJSVhrmst_RHEL4_IA64=FJSVhrmst-1.2.1-1.0.ia64.rpm

############################################################
# HRM package check
############################################################
if [ ! -f $FJSVhrm_RHEL ]; then
  Do_print "Error: HRM package can't find"
  exit 1
fi

HRM_UPDATE=0
HRM_RUN=0
HRM_SUPPORT_RHEL=0
HRM_SUPPORT_SUSE=0
SSC_SUPPORT_RHEL4_IA64=0

RFILE="/etc/redhat-release"
SFILE="/etc/SuSE-release"
ARCH=`uname -m`

if [ "$ARCH" != "i686" ] && [ "$ARCH" != "x86_64" ]; then
  Do_print "Error: Unsupported Operating System"
  exit 1
fi

############################################################
# Support check
############################################################
# Support Check for Redhat
if [ -f $RFILE ]; then
  HRM_SUPPORT_RHEL=1
fi

# Support Check for SuSE
#if [ -f $SFILE ]; then
#  if ( grep -q "SUSE Linux Enterprise Server" $SFILE ); then
#    HRM_SUPPORT_SUSE=1
#  fi
#fi

#
# check get SERVER_AGENT_READY is running currently
#
hrm_get_server_agent_ready_stop()
{
	fjsvhrmpid=`/bin/ps -eo pid,comm | /bin/grep -w 'hrmsched' | /usr/bin/awk '{print $1}'`
	if [ -n "$fjsvhrmpid" ]; then
		HRM_RUN=1
	fi

	fjsvhrmpid=`/bin/ps -eo pid,comm | /bin/grep 'FJSVhrm' | /usr/bin/awk '{print $1}'`
	if [ -n "$fjsvhrmpid" ]
	then
		HRM_RUN=1
		kill -TERM $fjsvhrmpid >/dev/null 2>&1

		hrmgetpid=`/bin/ps -eo pid,args | /bin/grep -w '/opt/FJSVhrm/bin/get SERVER_AGENT_READY' | /bin/grep -v grep | /usr/bin/awk '{print $1}'`
		if [ -n "$hrmgetpid" ]
		then
			kill -TERM $hrmgetpid >/dev/null 2>&1
			sleep 1
		fi
	fi
}

hrm_get_server_agent_ready_stop

############################################################
# FJSVhrm
############################################################
Do_install_FJSVhrm () {

  rpm -q FJSVhrmsr  > /dev/null 2>&1
  if [ "$?" = "0" ]; then
    HRM_UPDATE=1
  fi

  if [ "$HRM_SUPPORT_RHEL" = "1" ] ; then
    Do_print "install FJSVhrmsr, please wait..."
    sleep 1
    Do_rpm_UVH $FJSVhrm_RHEL
#  elif [ "$HRM_SUPPORT_SUSE" = "1" ] ; then
#    Do_print "install FJSVhrmsr, please wait..."
#    sleep 1
#    Do_rpm_UVH $FJSVhrm_SUSE
  else
    Do_print "Error: Unsupported Operating System"
    exit 1
  fi

  rpm -q FJSVhrmsr  > /dev/null 2>&1
  if [ "$?" = "0" ]; then
    if [ "$HRM_UPDATE" != "1" ] && [ "$SILENT" != "1" ]; then
      touch /var/opt/FJSVhrm/data/hrm_agent_enabled
    fi
    Do_print "HRM install was successful."
  else
    Do_print "Error: HRM install was failed"
    exit 1
  fi
}

Do_install_FJSVhrm

############################################################
# FJSVhrmst (SANTool)
############################################################
Do_install_SANTool () {
  if [ "$SSC_SUPPORT_RHEL4_IA64" != "1" ]; then
    return 0
  fi

  Do_print ""
  Do_print "install FJSVhrmst, please wait..."
  sleep 1

  rpm -q FJSVhrmst >/dev/null 2>&1
  if [ "$?" = "0" ]; then
    Do_print "Warning: Already FJSVhrmst installed."
    Do_print "If you upgrade to FJSVhrmst, and please backup & uninstall & install FJSVhrmst."
    return 0
  fi

  Do_rpm_IVH $FJSVhrmst_RHEL4_IA64

  rpm -q FJSVhrmst >/dev/null 2>&1
  if [ "$?" = "0" ]; then
    Do_print "FJSVhrmst install was successful."
  else
    Do_print "Error: FJSVhrmst install was failed."
    return 1
  fi
}

# Do_install_SANTool

############################################################
# FJSVhrm Update status check
############################################################
if [ "$HRM_UPDATE" = "1" ] && [ "$HRM_RUN" = "0" ]; then
  exit 0
fi

############################################################
# FJSVhrm Start
############################################################

cd /

if [ -f /var/opt/FJSVhrm/data/hrm_agent_enabled ]; then
  Do_print ""
  if [ -f /etc/rc.d/init.d/FJSVhrm ]; then
    /etc/rc.d/init.d/FJSVhrm start
  elif [ -f /etc/init.d/FJSVhrm ]; then
    /etc/init.d/FJSVhrm start
  fi
  Do_print "FJSVhrm start."
fi

exit 0
