#!/bin/sh
# HRM Install Checker for PRIMEQUEST/Linux, Copyright Fujitsu Limited 2007
# All Right Reserved

.  `dirname $0`/common_lib.sh

modelcode="R"		# W:PRIMEPOWER G:PRIMERGY S:SPARC_enterprise Q:PRIMEQUEST R:SIRIUS

echo "$title31"
echo "$title32"
echo "$title34"
echo "$title35"

hrmpkg="FJSVhrmsr"

#
# hostname check
#
section "$oschk_00"
init
r=`/bin/hostname`
x=`echo "$r" | tr -d '[\040-\177]'`
if [ "$x" != "" ]
then
        str1="$oschk_05"
fi
title  "$oschk_04" "$r"

#
# OS check
#
#  RedHat Enterprise Linux 5
#  VMware vSphere 4
#  RedHat Enterprise Linux Xen
#
relfile="/etc/redhat-release"
init
if [ -x /usr/bin/vmware ]		# is VMware
then
	vmware_version=`/usr/bin/vmware -v`
	osname="$vmware_version"
	ostype="vmware"

elif [ -f "$relfile" ]
then
	osname="RHEL"
	ostype="redhat"

	if grep "release 5" $relfile >/dev/null
	then
		osname="${osname}5"
	else
		# unsupported RedHat version
		str1="$oschk_06 `cat $relfile`"
	fi
else
	str1="$oschk_06 unknown"
fi
title  "$oschk_01" $osname" "`/bin/uname -r`" "`/bin/uname -m`

if [ "$nr_err" != 0 ]           # finish if failed
then
	if [ ! -f "NO_OS_CHECK" ]
	then
		end
	fi
fi


#
# Package Check
#
# target="FJSVpsa/0  libgcc/0  zip/0"
# target="FJSVpsa/0 glibc/0 libgcc/0 libstdc++/0 libunwind/0  zip/0"
target="FJSVpsa/0 rpm/0 gawk/0 glibc/0 grep/0 libgcc/0 bash/0 sed/0 perl/0 libstdc++/0 net-snmp/0"

init
section "$esfchk_04"
for data in $target
do
	init
	save="$IFS"; IFS="/"; set - $data ; IFS="$save"

	pkg="$1"
	c_ver="$2"
	c_rev="$3"
	ver=""
	if rpm -q $pkg >/dev/null
	then
		ver=`rpm -q --queryformat '%{VERSION}-%{RELEASE}' $pkg`

		if [ "$c_ver" != "0" ]
		then
			a_ver=`rpm -q --queryformat '%{VERSION}' $pkg`
			a_rev=`rpm -q --queryformat '%{RELEASE}' $pkg`

			nor_c_ver=`printf "%08.2f" "$c_ver"`	     # assume X.XX
			nor_a_ver=`printf "%08.2f" "$a_ver"`	     # assume X.XX

			if expr "$nor_c_ver" \> "$nor_a_ver" >/dev/null
			then
				str1=`printf "$esfchk_06" "$pkg" "$ver" "$ver_c"`
	
			elif  expr "$nor_c_ver" = "$nor_a_ver" >/dev/null
			then
				if expr "$c_rev" \> "$a_rev" >/dev/null
				then
					str1=`printf "$esfchk_06" "$pkg" "$ver" "$ver_c"`
				fi
			fi
		fi

	else
		str1=`printf "$esfchk_05" "$pkg"`
	fi
	title "$pkg" "$ver"
done

#
# module check
#
for mod in sg
do
	init
	if /sbin/lsmod | awk '{print $1}' | grep "^$mod\$" >/dev/null
	then
		:
	else
		str1="$esfchk_07"
	fi
	title "$mod"
done




#
# Disk Space
#
section "$dskchk_00"
for data in "/opt 10240 100000" "/var/opt 51200 100000"
do
	init
	set - $data
	targ=$1
	limitsize=$2	# required disk space when HRM is not installed yet
	enoughsize=$3	# expected disk space even if HRM is installed or not

	avail=`/bin/df -kP $targ | /bin/sed -n 2p | awk '{print $4}'`
	if [ "$avail" != "" ]
	then
		if rpm -q "$hrmpkg" >/dev/null
		then
			:
		elif [ $avail -lt "$limitsize" ]
		then
			str1=`printf "$dskchk_01"  $targ  $limitsize`
		fi

		if [ "$str1" = "" ]
		then
			if [ $avail -lt "$enoughsize" ]
			then
				str1=`printf "$dskchk_02"  $targ`
			fi
		fi

		title "$targ" "$avail Kbyte"
	fi
done



#
# Port check
# if /etc/services contains 9977 , print warning
#
section "$portchk_00"
for data in "9977 hrmport" "9978 hrmsana" 
do
	set - $data
	port=$1
	servname=$2

	init
	if grep "$port/tcp" /etc/services | grep -v '^#' | grep -v $servname >/dev/null ; then
		str1=`printf "$portchk_01" $port`
	fi
	title $port 
done




#
# HRM Package check
#
section "$hrmchk_00"
init
if rpm -q "$hrmpkg" >/dev/null
then
	ver=`rpm -q --queryformat '%{VERSION}-%{RELEASE}' $hrmpkg`

	#
	# Note: if version is 3.1.1 or less than 3.1.0, it contains 
	#  the tape rewind problem.
	#
	hrmver=`rpm -q --queryformat '%{VERSION}' $hrmpkg`  # 3.1 or 3.1.1 or 3.0.10
	vernum=`echo "$hrmver" | awk -F. '{printf "%d%d", $1, $2}'`
	if [ "$vernum" -lt 31 ]
	then
		str1="$hrmchk_04"
	fi

else
	ver=""
	str1="$hrmchk_01"
fi
title "$hrmpkg" "$ver"


#
# SDB agent check
#
section "$sdbagt_00"
init
sdb="not found"
if [ -f /opt/sdb/bin/sdb_timer.bin ]
then
        # sdb is installed
        str1="$sdbagt_01"

        if /bin/ps -eo args | grep '[/]opt/sdb/bin/sdb_timer.bin' >/dev/null
        then
                str1="$sdbagt_02"
        fi
fi
title "SDB RA"


if rpm -q "$hrmpkg" >/dev/null ; then
	:
else
	end
fi


#
# hrmsched check
#
section "$schchk_00"
init
if /bin/ps -el | grep hrmsched >/dev/null
then
	:				# sched is running
else
	if [ ! -f /var/opt/FJSVhrm/data/hrm_agent_enabled ]
	then
		str1="$schchk_01"
	fi

	if [ -f /var/opt/FJSVhrm/log/sched_log ]
	then
		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'for the specified address is already in use' >/dev/null
		then
			str1="$schchk_02"
		fi

		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'alive_check:hrm scheduler abnormally terminated' >/dev/null
		then
			str2="$schchk_03"
		fi

		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'alive_check:hrm scheduler ends normally.' >/dev/null
		then
			str3="$schchk_04"
		fi

		if [ "$str1" = "" -a "$str2" = "" -a "$str3" = "" ]
		then
			str1="$schchk_07"
		fi
	fi
fi
title "$schchk_10"


#
# devconf
#
if [ -f /var/opt/FJSVhrm/log/sched_log ]
then
	init
	if [ ! -f /var/opt/FJSVhrm/data/devconf_cur.xml ]
	then
		str1="$schchk_06"
	fi
	title "$schchk_11"
fi



end



