#!/bin/sh -
#
# HRM hrmsnap for IA-Linux Copyright Fujitsu Limited 2004-2007
# All Right Reserved
# $Id: hrmsnap.sh,v 1.5 2007/12/12 01:14:08 ochiai Exp $
#
# HRMsnap
#

version="3.3.1"
PATH=/bin:/usr/bin:/usr/sbin:$PATH export PATH

if [ "$HRM_temp" = "" ]
then
	HRM_bin="/opt/FJSVhrm/bin" export HRM_bin
	HRM_data="/var/opt/FJSVhrm/data" export HRM_data
	HRM_update="/opt/FJSVhrm/update" export HRM_update
	HRM_config="/var/opt/FJSVhrm/config" export HRM_config
	HRM_temp="/var/opt/FJSVhrm/temp" export HRM_temp
	HRM_log="/var/opt/FJSVhrm/log" export HRM_log
fi

snapdir=$HRM_temp/hrmsnap
tempdir=$HRM_temp/hrmsnap_temp
hostname=`/bin/hostname`
#snapfile=`/bin/date '+snap_%Y%m%d_%H%M%S'`"_${hostname}.slc"
#snapfile=`/bin/date '+snap_%Y%m%d_%H%M%S'`"_${hostname}.tar.gz"
snapfile=`/bin/date '+snap_%Y%m%d_%H%M%S'`"_${hostname}.hrm.zip"
snap_ext=zip

lockfile=$HRM_temp/hrmsnap/.lock
progshowdir=$tempdir/statshow

export tempdir snapfile snapdir model lockfile progshowdir snap_ext

#
# make work directories
#
if [ ! -d $tempdir ]
then
	mkdir $tempdir
fi
if [ ! -d $snapdir ]
then
	if mkdir $snapdir
	then
		:
	else
		echo "Error: failed to make snap directory.($snapdir)"
		exit 1
	fi
fi

if [ ! -d $progshowdir ]
then
        if mkdir $progshowdir
        then
                :
        else
                echo "Error: failed to make snap directory.($progshowdir)"
                exit 1
        fi
fi

#
# change stderr to stdout
#
exec 2>&1

#
# lock for progress
#
do_lock()
{
	n=1
        until /bin/ln -s /dev/null $lockfile 2>/dev/null 
        do
                sleep 1
                if [ $n -gt 10 ] ; then break; fi	# max 10 sec
                n=`expr $n + 1`
        done
}

do_unlock()
{
        rm $lockfile
}


#
# hrmsnap by hand
#
do_hrmsnap_byhand()
{
#	rm -f $lockfile
	echo "HRMsnap start..."
	$HRM_bin/hrmsnap_main.sh remcs >/dev/null 2>&1
	echo "HRMsnap complete."
	echo ""
	echo "directory: $snapdir"
	echo "filename : $snapfile"
	exit 0
}


#
# list snap file
#
do_list()
{
	exec 2>/dev/null
	cd $snapdir
	for f in `/bin/ls -1 snap*`
	do
		# lines=`wc -l < $f`
		# size=`head -1 $f | awk '/^begin/{print $3}'`
		
		header=`head -1 $f | awk '/^begin/{print $3}'`
		lines=`echo $header | awk -F, '{print $3}'`
		size=`echo $header | awk -F, '{print $2}'`
		
		size=`expr 0 + $size 2>/dev/null`
		if [ "$size" = "" ]
		then
			lines=0
			size=0
			rm $f
		else
			echo "$f $lines $size"
		fi
	done
	exit 0
}


#
# make archive
#
do_snap()
{
	if [ -f $snapdir/.snap_pid ]
	then
		if ! /bin/ps `cat $snapdir/.snap_pid` >/dev/null 2>&1	
		then
			echo "erase .snap_pid"
			rm $snapdir/.snap_pid
		else
			echo "another snap is already running"
			exit 2
		fi
		#if ! /bin/ps `cat $snapdir/.snap_pid` >/dev/null 2>&1	
		#then
		#	echo "another snap is already running"
		#	exit 2
		#else
		#	rm $snapdir/.snap_pid
		#fi
	fi

	rm -f $lockfile
	echo "0 1" > $snapdir/.snap_progress
	$HRM_bin/hrmsnap_main.sh "$@" >$snapdir/.snap_trace 2>&1 &

        if [ -f "$snapdir/.snap_trace" ] ; then
                mv "$snapdir/.snap_trace" "$HRM_log/hrmsnap_trace.log.0"
        fi

	echo $! > $snapdir/.snap_pid
	echo "$snapfile" > $snapdir/.snap_file
	$HRM_bin/hrmdate -u > $snapdir/.snap_begin
	$HRM_bin/hrmevent "I0914:snap is started."
	exit 0
}

#
# progress
#
do_progress()
{
	if [ ! -f $snapdir/.snap_progress ]
	then
		exit 1
	fi
	do_lock
	a=`awk '{print $1}' $snapdir/.snap_progress`
	b=`awk '{print $2}' $snapdir/.snap_progress`
	c=`/bin/cat $snapdir/.snap_begin`
	/bin/echo "hrmsnap," `$HRM_bin/calcprogress $a $b $c`
	# $HRM_bin/calcprogress $a $b `/bin/cat $snapdir/.snap_begin`
	do_unlock
	exit 0
}


#
# cancel
#
do_cancel()
{
	exec >/dev/null 2>&1

	pid=`cat $snapdir/.snap_pid`
	if [ "$pid" = "" ]
	then
		exit 1
	fi
	pgid=`/bin/ps -p $pid -o pgid= | /bin/sed 's/ //g'`
	if [ "$pgid" = "" ]
	then
		exit 1
	fi
	kill -9 -${pgid}
	sleep 2
#	kill -9 -${pgid}
#	sleep 2
	rm -rf $HRM_temp/hrmsnap_temp/*
	rm -f $snapdir/.snap_pid
	rm -f $snapdir/.snap_result
	filename=`cat $snapdir/.snap_file`
	rm -f "$snapdir/$filename"
	rm -f "$snapdir/${filename}.uue"
	rm -f $lockfile
	echo "1 1" > $snapdir/.snap_progress
	$HRM_bin/hrmevent "I0931:snap is canceled."
	$HRM_bin/hrmevent "I0915:snap is finished."
	exit 0
}


#
# lastsnap
#
do_lastsnap()
{
	/bin/cat $snapdir/.snap_result 2>/dev/null
	exit 0
}



#
# make archive
#
do_get()
{
	name=$1
	line1=$2
	line2=$3

	uue=$snapdir/${name}
	if [ ! -f $uue ]
	then
		echo "$name is not found."
		exit 1
	fi

	sed -n "${line1},${line2}p" $uue
	exit 0
}


#
# delete archive
#
do_delete()
{
	name=$1
	uue="$snapdir/${name}"
	if [ -f $uue ]
	then
		rm -f $uue
		exit 0
	else
		echo "\"$name\"($uue) is not valid file"
		exit 1
	fi
}


#
# logsize
#
do_logsize()
{
	exec 2>/dev/null
        s_pkg=`/bin/rpm -qai | /usr/bin/wc -c`
	s_soft=`expr $s_pkg / 1000`

        targ="/var/log/messages*"
        s_msg=`/usr/bin/du -sk $targ | awk 'BEGIN{sum=0}{sum = sum + $1}END{print sum}'`

        targ="$HRM_update $HRM_log"
        s_hrm=`/usr/bin/du -sk $targ | awk 'BEGIN{sum=0}{sum = sum + $1}END{print sum}'`
        s_data=`/usr/bin/du -sk $HRM_data | awk 'BEGIN{sum=0}{sum = sum + $1}END{print sum}'`        

        targ="/var/log/gamevlog.log  /usr/dpt/dptelog.*"
        s_hard=`/usr/bin/du -sk $targ | awk 'BEGIN{sum=0}{sum = sum + $1}END{print sum}'`        
        s_hard=`expr $s_hard + $s_data`  # add dmesg

        echo "hard " `expr $s_hard + $s_msg + 16`
        echo "soft " `expr $s_soft + $s_msg + 16`
        echo "hrm  $s_hrm"
        echo "hardsoft " `expr $s_hard + $s_soft + $s_msg + 16`
        exit 0
}




#
#  hrmsnap w/o parameter by hand
#
if [ "$1" = "" ]
then
	do_hrmsnap_byhand
	exit 0
fi

#
# all modules require to support following commands
#
case $1 in
HRMstart)
	exit 0
	;;
HRMend)
#	exit 0
	do_cancel
	;;
version)
	echo "$version $Date: 2007/12/12 01:14:08 $"
	exit 0
	;;
reload)
	exit 0
	;;
snap)	
	do_snap "$2" "$3" "$4"
	;;
list)	
	do_list;
	;;
get)	
	do_get "$2" "$3" "$4";
	;;
delete)	
	do_delete "$2"
	;;
progress)
	do_progress
	;;
cancel)
	do_cancel
	;;
lastsnap)
	do_lastsnap
	;;
logsize)
	do_logsize
	;;
*)
	echo "Error: unsupported command.($1)"
	exit 1
esac


